"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var AttributePath_1 = require("./AttributePath");
var FUNCTION_EXPRESSION_TAG = 'AmazonDynamoDbFunctionExpression';
var EXPECTED_TOSTRING = "[object " + FUNCTION_EXPRESSION_TAG + "]";
/**
 * An object representing a DynamoDB function expression.
 */
var FunctionExpression = /** @class */ (function () {
    function FunctionExpression(name) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        this.name = name;
        this[Symbol.toStringTag] = FUNCTION_EXPRESSION_TAG;
        this.args = args;
    }
    FunctionExpression.prototype.serialize = function (attributes) {
        var expressionSafeArgs = this.args.map(function (arg) { return AttributePath_1.AttributePath.isAttributePath(arg)
            ? attributes.addName(arg)
            : attributes.addValue(arg); });
        return this.name + "(" + expressionSafeArgs.join(', ') + ")";
    };
    /**
     * Evaluate whether the provided value is a FunctionExpression object.
     */
    FunctionExpression.isFunctionExpression = function (arg) {
        return arg instanceof FunctionExpression
            || Object.prototype.toString.call(arg) === EXPECTED_TOSTRING;
    };
    return FunctionExpression;
}());
exports.FunctionExpression = FunctionExpression;
//# sourceMappingURL=FunctionExpression.js.map